@@ -24,7 +24,7 @@ varpoord <- function(Y, w_final,
                      q = NULL,
                      datasetX = NULL,
                      percentage = 60,
-                     order_quant = 50,
+                     order_quant = 50L,
                      alpha = 20,
                      confidence = .95,
                      outp_lin = FALSE,
@@ -43,7 +43,7 @@ varpoord <- function(Y, w_final,
   outp_lin <- check_var(vars = outp_lin, varn = "outp_lin", varntype = "logical") 
   outp_res <- check_var(vars = outp_res, varn = "outp_res", varntype = "logical") 
 
-  p <- check_var(vars = percentage, varn = "percentage", varntype = "numeric0100") 
+  percentage <- check_var(vars = percentage, varn = "percentage", varntype = "numeric0100") 
   order_quant <- check_var(vars = order_quant, varn = "order_quant", varntype = "integer0100") 
   alpha <- check_var(vars = alpha, varn = "alpha", varntype = "numeric0100") 
   confidence <- check_var(vars = confidence, varn = "confidence", varntype = "numeric01") 
@@ -89,9 +89,19 @@ varpoord <- function(Y, w_final,
                           Ynrow = Ynrow, mustbedefined = FALSE,
                           isnumeric = TRUE, isvector = TRUE)
 
+  ID_level1 <- check_var(vars = ID_level1, varn = "ID_level1",
+                         dataset = dataset, ncols = 1,
+                         Ynrow = Ynrow, ischaracter = TRUE)
+
+  ID_level2 <- check_var(vars = ID_level2, varn = "ID_level2",
+                         dataset = dataset, ncols = 1, 
+                         Ynrow = Ynrow, ischaracter = TRUE,
+                         namesID1 = names(ID_level1), periods = period)
+
   H <- check_var(vars = H, varn = "H", dataset = dataset,
                  ncols = 1, Yncol = 0, Ynrow = Ynrow,
-                 ischaracter = TRUE, dif_name = "dataH_stratas")
+                 ischaracter = TRUE, namesID1 = names(ID_level1),
+                 dif_name = "dataH_stratas")
 
   sort <- check_var(vars = sort, varn = "sort",
                     dataset = dataset, ncols = 1,
@@ -108,15 +118,6 @@ varpoord <- function(Y, w_final,
                    mustbedefined = FALSE, duplicatednames = TRUE,
                    grepls = "__")
 
-  ID_level1 <- check_var(vars = ID_level1, varn = "ID_level1",
-                         dataset = dataset, ncols = 1,
-                         Ynrow = Ynrow, ischaracter = TRUE)
-
-  ID_level2 <- check_var(vars = ID_level2, varn = "ID_level2",
-                         dataset = dataset, ncols = 1, 
-                         Ynrow = Ynrow, ischaracter = TRUE,
-                         namesID1 = names(ID_level1), periods = period)
-
   PSU <- check_var(vars = PSU, varn = "PSU", dataset = dataset,
                    ncols = 1, Yncol = 0, Ynrow = Ynrow,
                    ischaracter = TRUE, namesID1 = names(ID_level1))
@@ -128,7 +129,7 @@ varpoord <- function(Y, w_final,
   if(!is.null(X)) {
        X <- check_var(vars = X, varn = "X", dataset = datasetX,
                       check.names = TRUE, isnumeric = TRUE,
-                      grepls = "__", dif_name = c(names(period) , "g", "q"))
+                      dif_name = c(names(period) , "g", "q"))
        Xnrow <- nrow(X)
 
        ind_gr <- check_var(vars = ind_gr, varn = "ind_gr",
@@ -157,6 +158,7 @@ varpoord <- function(Y, w_final,
    }
 
  # N_h
+ np <- sum(ncol(period))
  if (!is.null(N_h)) {
    N_h <- data.table(N_h)
    if (anyNA(N_h)) stop("'N_h' has missing values")
@@ -165,21 +167,19 @@ varpoord <- function(Y, w_final,
 
    nams <- c(names(period), names(H))
    if (all(nams %in% names(N_h))) {N_h[, (nams) := lapply(.SD, as.character), .SDcols = nams]
-   } else stop(paste0("All strata titles of 'H'", ifelse(!is.null(period), "and periods titles of 'period'", ""), " have not in 'N_h'"))
+       } else stop(paste0("All strata titles of 'H'", ifelse(!is.null(period), "and periods titles of 'period'", ""), " have not in 'N_h'"))
 
    if (is.null(period)) {
      if (any(is.na(merge(unique(H), N_h, by = names(H), all.x = TRUE)))) stop("'N_h' is not defined for all strata")
      if (any(duplicated(N_h[, head(names(N_h), -1), with = FALSE]))) stop("Strata values for 'N_h' must be unique")
-   } else { pH <- data.table(period, H)
-   if (any(is.na(merge(unique(pH), N_h, by = names(pH), all.x = TRUE)))) stop("'N_h' is not defined for all strata and periods")
-   if (any(duplicated(N_h[, head(names(N_h), -1), with = FALSE]))) stop("Strata values for 'N_h' must be unique in all periods")
-   pH <- NULL
-   }
-   setkeyv(N_h, names(N_h)[c(1 : (1 + np))])
+       } else { pH <- data.table(period, H)
+                if (any(is.na(merge(unique(pH), N_h, by = names(pH), all.x = TRUE)))) stop("'N_h' is not defined for all strata and periods")
+                if (any(duplicated(N_h[, head(names(N_h), -1), with = FALSE]))) stop("Strata values for 'N_h' must be unique in all periods")
+                pH <- NULL }
+     setkeyv(N_h, names(N_h)[c(1 : (1 + np))])
  }
 
   N <- dataset <- datasetX <- NULL
-  np <- sum(ncol(period))
 
   if (is.null(Y_thres)) Y_thres <- Y
   if (is.null(wght_thres)) wght_thres <- w_final
